<?php
/**
 * Excavator: Customizer
 *
 * @subpackage Excavator
 * @since 1.0
 */

use WPTRT\Customize\Section\Luzuk_Excavator_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Luzuk_Excavator_Button::class );

	$manager->add_section(
		new Luzuk_Excavator_Button( $manager, 'luzuk_excavator_pro', [
			'title' => __( 'Excavator Pro', 'excavator' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'excavator' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/themes/excavator-wp-theme/', 'excavator')
		] )
	);

} );


// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'excavator-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'excavator-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function luzuk_excavator_customize_register( $wp_customize ) {

	$wp_customize->add_setting('luzuk_excavator_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('luzuk_excavator_logo_padding',array(
		'label' => __('Logo Margin','excavator'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_excavator_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_float'
	));
	$wp_customize->add_control('luzuk_excavator_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','excavator'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_excavator_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_float'
	));
	$wp_customize->add_control('luzuk_excavator_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','excavator'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_excavator_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_float'
	));
	$wp_customize->add_control('luzuk_excavator_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','excavator'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_excavator_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_float'
 	));
 	$wp_customize->add_control('luzuk_excavator_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','excavator'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('luzuk_excavator_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_excavator_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','excavator'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_excavator_site_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_site_title_color', array(
		'label' => 'Title Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_setting('luzuk_excavator_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_excavator_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_excavator_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','excavator'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_excavator_site_tagline_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_site_tagline_color', array(
		'label' => 'Tagline Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_panel( 'luzuk_excavator_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'excavator' ),
		'description' => __( 'Description of what this panel does.', 'excavator' ),
	) );

	$wp_customize->add_section( 'luzuk_excavator_theme_options_section', array(
    	'title'      => __( 'General Settings', 'excavator' ),
		'priority'   => 30,
		'panel' => 'luzuk_excavator_panel_id'
	) );

	$wp_customize->add_setting('luzuk_excavator_theme_options',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_excavator_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','excavator'),
		'section' => 'luzuk_excavator_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','excavator'),
		   'Right Sidebar' => __('Right Sidebar','excavator'),
		   'One Column' => __('One Column','excavator'),
		   'Grid Layout' => __('Grid Layout','excavator')
		),
	));

	$wp_customize->add_setting('luzuk_excavator_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_excavator_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','excavator'),
        'section' => 'luzuk_excavator_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','excavator'),
            'Right Sidebar' => __('Right Sidebar','excavator'),
            'One Column' => __('One Column','excavator')
        ),
	));

	$wp_customize->add_setting('luzuk_excavator_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_excavator_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','excavator'),
        'section' => 'luzuk_excavator_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','excavator'),
            'Right Sidebar' => __('Right Sidebar','excavator'),
            'One Column' => __('One Column','excavator')
        ),
	));

	$wp_customize->add_setting('luzuk_excavator_archive_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_excavator_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','excavator'),
        'section' => 'luzuk_excavator_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','excavator'),
            'Right Sidebar' => __('Right Sidebar','excavator'),
            'One Column' => __('One Column','excavator'),
            'Grid Layout' => __('Grid Layout','excavator')
        ),
	));

	$wp_customize->add_setting( 'luzuk_excavator_boxfull_width', array(
		'default'           => '',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	
	$wp_customize->add_control( 'luzuk_excavator_boxfull_width', array(
		'label'    => __( 'Section Width', 'excavator' ),
		'section'  => 'luzuk_excavator_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'container'  => __('Box Width', 'excavator'),
			'container-fluid' => __('Full Width', 'excavator'),
			'none' => __('None', 'excavator')
		),
	));

	$wp_customize->add_setting( 'luzuk_excavator_dropdown_anim', array(
		'default'           => 'None',
		'sanitize_callback' => 'luzuk_excavator_sanitize_choices'
	));
	$wp_customize->add_control( 'luzuk_excavator_dropdown_anim', array(
		'label'    => __( 'Menu Dropdown Animations', 'excavator' ),
		'section'  => 'luzuk_excavator_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'bounceInUp'  => __('bounceInUp', 'excavator'),
			'fadeInUp' => __('fadeInUp', 'excavator'),
			'zoomIn'    => __('zoomIn', 'excavator'),
			'None'    => __('None', 'excavator')
		),
	));
 
	//Header
	$wp_customize->add_section( 'luzuk_excavator_header' , array(
    	'title'    => __( 'Header Settings', 'excavator' ),
		'priority' => null,
		'panel' => 'luzuk_excavator_panel_id'
	) );

	$wp_customize->add_setting('luzuk_excavator_header_toptext',array(
		'default' => 'Join Our Team. Are You Ready To Change The Game?',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_header_toptext',array(
	   	'type' => 'text',
	   	'label' => __('Top Head Text','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	

	$wp_customize->add_setting('luzuk_excavator_twitterlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_twitterlink',array(
	   	'type' => 'url',
	   	'label' => __('Twitter Icon Link','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting('luzuk_excavator_instalink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_instalink',array(
	   	'type' => 'url',
	   	'label' => __('Instagram Icon Link','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));


	$wp_customize->add_setting('luzuk_excavator_linkedinlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_linkedinlink',array(
	   	'type' => 'url',
	   	'label' => __('Linkedin Icon Link','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting('luzuk_excavator_fblink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_fblink',array(
	   	'type' => 'url',
	   	'label' => __('Facebook Icon Link','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));
	

	$wp_customize->add_setting('luzuk_excavator_header_mailtext',array(
		'default' => 'Send Us',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_header_mailtext',array(
	   	'type' => 'text',
	   	'label' => __('Mail Title','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting('luzuk_excavator_header_mail',array(
		'default' => 'demo@example.com',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_header_mail',array(
	   	'type' => 'text',
	   	'label' => __('Mail Text','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting('luzuk_excavator_header_phonetext',array(
		'default' => 'Phone No :',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_header_phonetext',array(
	   	'type' => 'text',
	   	'label' => __('Phone Number Text','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting('luzuk_excavator_header_phoneno',array(
		'default' => '(00) 123-456-789',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_header_phoneno',array(
	   	'type' => 'text',
	   	'label' => __('Phone Number','excavator'),
	   	'section' => 'luzuk_excavator_header',
	));

	$wp_customize->add_setting( 'luzuk_excavator_headertopbg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headertopbg_col', array(
		'label' => 'Top Head BG Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headerbottombg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headerbottombg_col', array(
		'label' => 'Bottom Head BG Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headermiddlebrd_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headermiddlebrd_col', array(
		'label' => 'Middle Border Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headertophedtext_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headertophedtext_col', array(
		'label' => 'Top Head Text Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headertophedicons_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headertophedicons_col', array(
		'label' => 'Top Head Icons Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headertophediconshrv_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headertophediconshrv_col', array(
		'label' => 'Top Head Icons Hover Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headersearchbrd_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headersearchbrd_col', array(
		'label' => 'Search Form Border Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headersearchplaceholder_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headersearchplaceholder_col', array(
		'label' => 'Search Form Placeholder Color',
		'section' => 'luzuk_excavator_header',
	)));
	
	$wp_customize->add_setting( 'luzuk_excavator_headersearchicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headersearchicon_col', array(
		'label' => 'Search Icon Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headersearchformbg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headersearchformbg_col', array(
		'label' => 'Search Form BG Color',
		'section' => 'luzuk_excavator_header',
	)));
	

	$wp_customize->add_setting( 'luzuk_excavator_headermailicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headermailicon_col', array(
		'label' => 'Mail Icon Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headermailtxt_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headermailtxt_col', array(
		'label' => 'Mail Text Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_headermailnum_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_headermailnum_col', array(
		'label' => 'Mail Number Color',
		'section' => 'luzuk_excavator_header',
	)));


	$wp_customize->add_setting( 'luzuk_excavator_menu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_menu_color', array(
		'label' => 'Menu Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_menuhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_menuhover_color', array(
		'label' => 'Menu Hover Color',
		'section' => 'luzuk_excavator_header',
	)));


	$wp_customize->add_setting( 'luzuk_excavator_submenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_submenu_color', array(
		'label' => 'Submenu Text Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_submenubg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_submenubg_color', array(
		'label' => 'Submenu BG Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_header_phnicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_header_phnicon_color', array(
		'label' => 'Phone Number Icon Color',
		'section' => 'luzuk_excavator_header',
	)));

	
	$wp_customize->add_setting( 'luzuk_excavator_header_phntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_header_phntext_color', array(
		'label' => 'Phone Number Text Color',
		'section' => 'luzuk_excavator_header',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_header_phnnum_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_header_phnnum_color', array(
		'label' => 'Phone Number Color',
		'section' => 'luzuk_excavator_header',
	)));



	//home page slider
	$wp_customize->add_section( 'luzuk_excavator_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'excavator' ),
		'description'=> __('<b>Note :</b> Please Add Image in 1500*600 Ratio.','excavator'),
		'priority' => null,
		'panel' => 'luzuk_excavator_panel_id'
	) );

	$wp_customize->add_setting('luzuk_excavator_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'luzuk_excavator_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_excavator_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide Slider','excavator'),
	   	'section' => 'luzuk_excavator_slider_section',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'luzuk_excavator_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'luzuk_excavator_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'luzuk_excavator_slider' . $count, array(
			'label' => __('Select A Page', 'excavator' ),
			'section' => 'luzuk_excavator_slider_section',
			'type' => 'dropdown-pages'
		));
	}

	$wp_customize->add_setting('luzuk_excavator_sliderbtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_sliderbtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Slider Button Link','excavator'),
	   	'section' => 'luzuk_excavator_slider_section',
	));


	$wp_customize->add_setting( 'luzuk_excavator_slider_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_excavator_slider_section',
	)));
	
	$wp_customize->add_setting( 'luzuk_excavator_slider_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_btntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_btnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_btnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_btnbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_btnbrd_color', array(
		'label' => 'Button Border Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_btntexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_btntexthover_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_excavator_slider_section',
	)));
	
	$wp_customize->add_setting( 'luzuk_excavator_slider_arrowicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_arrowicon_color', array(
		'label' => 'Arrow Icon Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_arrowbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_arrowbg_color', array(
		'label' => 'Arrow BG Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_arrowbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_arrowbrd_color', array(
		'label' => 'Arrow Border Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_slider_arrowbghrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_slider_arrowbghrv_color', array(
		'label' => 'Arrow BG Hover Color',
		'section' => 'luzuk_excavator_slider_section',
	)));

	
	// aboutus Section
	$wp_customize->add_section('luzuk_excavator_aboutus_section',array(
		'title'	=> __('Aboutus Settings','excavator'),
		'description'=> __('<b>Note :</b> This section will appear below the slider.','excavator'),
		'panel' => 'luzuk_excavator_panel_id',
	));

	$wp_customize->add_setting(
    	'luzuk_excavator_aboutus_image',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_excavator_aboutus_image',
	        array(
			    'label'   		=> __('Image','excavator'),
				'description'   		=> __('Image size 650*523','excavator'),
	            'section' => 'luzuk_excavator_aboutus_section',
	            'settings' => 'luzuk_excavator_aboutus_image',
	        )
	    )
	);

	$wp_customize->add_setting('luzuk_excavator_aboutussubheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutussubheading',array(
	   	'type' => 'text',
	   	'label' => __('Sub Heading','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutusheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutusheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutusdescription',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutusdescription',array(
	   	'type' => 'text',
	   	'label' => __('Description','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutuslist1',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutuslist1',array(
	   	'type' => 'text',
	   	'label' => __('List 1','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutuslist2',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutuslist2',array(
	   	'type' => 'text',
	   	'label' => __('List 2','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutuslist3',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutuslist3',array(
	   	'type' => 'text',
	   	'label' => __('List 3','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutuslist4',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_aboutuslist4',array(
	   	'type' => 'text',
	   	'label' => __('List 4','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutusgetstartedbtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_aboutusgetstartedbtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Get Started Button Link','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_excavator_aboutusplayvideobtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_excavator_aboutusplayvideobtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Play Video Button Link','excavator'),
	   	'section' => 'luzuk_excavator_aboutus_section',
	));

	
	$wp_customize->add_setting( 'luzuk_excavator_aboutussubheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutussubheading_color', array(
		'label' => 'SubHeading Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutussubheadingbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutussubheadingbrd_color', array(
		'label' => 'SubHeading Border Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusheading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusdescription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusdescription_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutuslisticon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutuslisticon_color', array(
		'label' => 'Lists Icon Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));
	
	$wp_customize->add_setting( 'luzuk_excavator_aboutuslists_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutuslists_color', array(
		'label' => 'Lists Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	
	$wp_customize->add_setting( 'luzuk_excavator_aboutusgetstartedtext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusgetstartedtext_color', array(
		'label' => 'Get Started Button Text Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusgetstartedbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusgetstartedbg_color', array(
		'label' => 'Get Started Button BG Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusgetstartedbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusgetstartedbrd_color', array(
		'label' => 'Get Started Button Border Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusgetstartedtexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusgetstartedtexthover_color', array(
		'label' => 'Get Started Button Text Hover Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusplayavideotext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusplayavideotext_color', array(
		'label' => 'Play Video Button Text Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusplayavideobg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusplayavideobg_color', array(
		'label' => 'Play Video Button BG Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusplayavideoicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusplayavideoicon_color', array(
		'label' => 'Play Video Button Icon Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusplayavideoiconbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusplayavideoiconbg_color', array(
		'label' => 'Play Video Button Icon BG Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusplayavideotexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusplayavideotexthrv_color', array(
		'label' => 'Play Video Button Text Hover Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_aboutusimgbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_aboutusimgbrd_color', array(
		'label' => 'Image Border Color',
		'section' => 'luzuk_excavator_aboutus_section',
	)));
	

	// services Section
	$wp_customize->add_section('luzuk_excavator_services_section',array(
		'title'	=> __('Services Settings','excavator'),
		'description'=> __('<b>Note :</b> This section will appear below the Aboutus. Please Add Image size 379*499','excavator'),
		'panel' => 'luzuk_excavator_panel_id',
	));


	$wp_customize->add_setting('luzuk_excavator_servicesheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_excavator_servicesheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','excavator'),
	   	'section' => 'luzuk_excavator_services_section',
	));

	$pages = get_pages(); // Retrieve pages
	$page_options = array(); // Initialize page options array
	foreach ($pages as $page) {
		$page_options[$page->ID] = $page->post_title; // Store page ID and title in options array
	}

	$wp_customize->add_setting('luzuk_excavator_page_setting_1', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_excavator_page_setting_1', array(
		'label'    => __('Select Page 1', 'excavator'),
		'section'  => 'luzuk_excavator_services_section', 
		'type'     => 'dropdown-pages',
	));



	$wp_customize->add_setting('luzuk_excavator_page_setting_2', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_excavator_page_setting_2', array(
		'label'    => __('Select Page 2', 'excavator'),
		'section'  => 'luzuk_excavator_services_section', 
		'type'     => 'dropdown-pages',
	));


	$wp_customize->add_setting('luzuk_excavator_page_setting_3', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_excavator_page_setting_3', array(
		'label'    => __('Select Page 3', 'excavator'),
		'section'  => 'luzuk_excavator_services_section', 
		'type'     => 'dropdown-pages',
	));

	
	$wp_customize->add_setting( 'luzuk_excavator_services_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_excavator_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_services_headbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_headbrd_color', array(
		'label' => 'Heading Border Color',
		'section' => 'luzuk_excavator_services_section',
	)));


	$wp_customize->add_setting( 'luzuk_excavator_services_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_excavator_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_services_titlebrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_titlebrd_color', array(
		'label' => 'Title Border Color',
		'section' => 'luzuk_excavator_services_section',
	)));


	$wp_customize->add_setting( 'luzuk_excavator_services_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_btntext_color', array(
		'label' => 'View More Text Color',
		'section' => 'luzuk_excavator_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_services_btntextbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_btntextbg_color', array(
		'label' => 'View More BG Color',
		'section' => 'luzuk_excavator_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_services_btntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_services_btntexthrv_color', array(
		'label' => 'View More Text Hover Color',
		'section' => 'luzuk_excavator_services_section',
	)));
	

	//Footer
    $wp_customize->add_section( 'luzuk_excavator_footer', array(
    	'title'  => __( 'Footer Settings', 'excavator' ),
		'priority' => null,
		'panel' => 'luzuk_excavator_panel_id'
	) );

	$wp_customize->add_setting('luzuk_excavator_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'luzuk_excavator_sanitize_checkbox'
    ));
    $wp_customize->add_control('luzuk_excavator_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','excavator'),
       'section' => 'luzuk_excavator_footer'
    ));

    $wp_customize->add_setting('luzuk_excavator_footer_copy', array(
		'default'           => 'Copyright © 2024 Construction Wordpress Themes. All rights reserved.',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_excavator_footer_copy', array(
		'label'       => __('Copyright Text', 'excavator'),
		'section'     => 'luzuk_excavator_footer',
		'setting'     => 'luzuk_excavator_footer_copy',
		'type'        => 'text',
		'description' => __('<b>This feature is only available in the premium version.</b>', 'excavator'),
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));	

	$wp_customize->add_setting('luzuk_excavator_footer_copylink', array(
		'default'           => 'https://www.luzuk.com/top/wordpress-themes/construction/',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_excavator_footer_copylink', array(
		'label'    => __('Copyright Link', 'excavator'),
		'section'  => 'luzuk_excavator_footer',
		'setting'  => 'luzuk_excavator_footer_copylink',
		'type'     => 'text',
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));

	$wp_customize->add_setting( 'luzuk_excavator_footertext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footertext_color', array(
		'label' => 'Text Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footeractivemenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footeractivemenu_color', array(
		'label' => 'Active Menu Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footerbg_color', array(
		'label' => 'BG Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footercopyright_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footercopyright_color', array(
		'label' => 'Copyright Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footercopyrightinnerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footercopyrightinnerbg_color', array(
		'label' => 'Inner BG Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footerscrolltotoptext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footerscrolltotoptext_color', array(
		'label' => 'Scroll To Top Text Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footerscrolltotopbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footerscrolltotopbg_color', array(
		'label' => 'Scroll To Top BG Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footerscrolltotoptexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footerscrolltotoptexthover_color', array(
		'label' => 'Scroll To Top Text Hover Color',
		'section' => 'luzuk_excavator_footer',
	)));

	$wp_customize->add_setting( 'luzuk_excavator_footerscrolltotophover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_excavator_footerscrolltotophover_color', array(
		'label' => 'Scroll To Top Hover Color',
		'section' => 'luzuk_excavator_footer',
	)));




	

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'luzuk_excavator_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'luzuk_excavator_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'luzuk_excavator_customize_register' );

function luzuk_excavator_customize_partial_blogname() {
	bloginfo( 'name' );
}

function luzuk_excavator_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if (class_exists('WP_Customize_Control')) {

   	class Luzuk_Excavator_Fontawesome_Icon_Chooser extends WP_Customize_Control {

      	public $type = 'icon';

      	public function render_content() { ?>
	     	<label>
	            <span class="customize-control-title">
	               <?php echo esc_html($this->label); ?>
	            </span>

	            <?php if ($this->description) { ?>
	                <span class="description customize-control-description">
	                   <?php echo wp_kses_post($this->description); ?>
	                </span>
	            <?php } ?>

	            <div class="excavator-selected-icon">
	                <i class="fa <?php echo esc_attr($this->value()); ?>"></i>
	                <span><i class="fa fa-angle-down"></i></span>
	            </div>

	            <ul class="excavator-icon-list clearfix">
	                <?php
	                $luzuk_excavator_font_awesome_icon_array = luzuk_excavator_font_awesome_icon_array();
	                foreach ($luzuk_excavator_font_awesome_icon_array as $luzuk_excavator_font_awesome_icon) {
	                   $icon_class = $this->value() == $luzuk_excavator_font_awesome_icon ? 'icon-active' : '';
	                   echo '<li class=' . esc_attr($icon_class) . '><i class="' . esc_attr($luzuk_excavator_font_awesome_icon) . '"></i></li>';
	                }
	                ?>
	            </ul>
	            <input type="hidden" value="<?php $this->value(); ?>" <?php $this->link(); ?> />
	        </label>
	        <?php
      	}
  	}
}
function luzuk_excavator_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'luzuk_excavator_customizer_script' );